@@ -24,6 +24,7 @@ import (
 	"time"
 
 	"github.com/spf13/cobra"
+	"k8s.io/client-go/rest"
 
 	"knative.dev/client/pkg/kn/config"
 	"knative.dev/client/pkg/kn/plugin"
@@ -35,12 +36,15 @@ func init() {
 }
 
 func main() {
-	err := run(os.Args[1:])
-	if err != nil && len(os.Args) > 1 {
-		printError(err)
-		// This is the only point from where to exit when an error occurs
-		os.Exit(1)
-	}
+	// Override client-go's warning handler to give us nicely printed warnings.
+	rest.SetDefaultWarningHandler(
+		rest.NewWarningWriter(os.Stderr, rest.WarningWriterOptions{
+			// only print a given warning the first time we receive it
+			Deduplicate: true,
+		}),
+	)
+
+	os.Exit(runWithExit(os.Args[1:]))
 }
 
 // runError is used when during the execution of a command/plugin an error occurs and
@@ -54,6 +58,14 @@ func (e *runError) Error() string {
 	return e.err.Error()
 }
 
+func runWithExit(args []string) int {
+	if err := run(args); err != nil {
+		printError(err)
+		return 1
+	}
+	return 0
+}
+
 // Run the main program. Args are the args as given on the command line (excluding the program name itself)
 func run(args []string) error {
 	// Parse config & plugin flags early to read in configuration file
