@@ -28,12 +28,22 @@ readonly OLM_NAMESPACE="openshift-marketplace"
 # if you want to setup the nightly serving/eventing, set `release-next` OR
 # set release branch name for example: release-v0.19.1
 readonly SERVING_BRANCH="release-next"
-# Pin the version due to issue in current nightly version
 readonly EVENTING_BRANCH="release-next"
 
+# The value should be updated once S-O release branch is cut
+readonly SERVERLESS_BRANCH="main"
+
 # Determine if we're running locally or in CI.
 if [ -n "$OPENSHIFT_BUILD_NAMESPACE" ]; then
-  readonly TEST_IMAGE_TEMPLATE="${IMAGE_FORMAT//\$\{component\}/knative-client-test-{{.Name}}}"
+  readonly TEST_IMAGE_TEMPLATE=$(cat <<-END
+{{- with .Name }}
+{{- if eq . "helloworld"}}$KNATIVE_CLIENT_TEST_HELLOWORLD{{end -}}
+{{- if eq . "grpc-ping"}}$KNATIVE_CLIENT_TEST_GRPC_PING{{end -}}
+{{- if eq . "servingcontainer"}}$KNATIVE_CLIENT_TEST_SERVINGCONTAINER{{end -}}
+{{- if eq . "sidecarcontainer"}}$KNATIVE_CLIENT_TEST_SIDECARCONTAINER{{end -}}
+{{end -}}
+END
+)
 elif [ -n "$DOCKER_REPO_OVERRIDE" ]; then
   readonly TEST_IMAGE_TEMPLATE="${DOCKER_REPO_OVERRIDE}/{{.Name}}"
 elif [ -n "$BRANCH" ]; then
@@ -104,7 +114,7 @@ run_client_e2e_tests(){
   go test \
     ./test/e2e \
     -v -timeout=$E2E_TIMEOUT -mod=vendor \
-    --imagetemplate $TEST_IMAGE_TEMPLATE \
+    --imagetemplate "$TEST_IMAGE_TEMPLATE" \
     ${run_append} || failed=$?
 
   return $failed
