@@ -18,15 +18,15 @@ import (
 	"errors"
 	"testing"
 
-	"gotest.tools/assert"
+	"gotest.tools/v3/assert"
 
-	"knative.dev/client/pkg/sources/v1alpha2"
+	v1 "knative.dev/client/pkg/sources/v1"
 	"knative.dev/client/pkg/util"
 )
 
 func TestApiServerSourceDelete(t *testing.T) {
 
-	apiServerClient := v1alpha2.NewMockKnAPIServerSourceClient(t, "testns")
+	apiServerClient := v1.NewMockKnAPIServerSourceClient(t, "testns")
 	apiServerRecorder := apiServerClient.Recorder()
 
 	apiServerRecorder.DeleteAPIServerSource("testsource", nil)
@@ -39,8 +39,7 @@ func TestApiServerSourceDelete(t *testing.T) {
 }
 
 func TestDeleteWithError(t *testing.T) {
-
-	apiServerClient := v1alpha2.NewMockKnAPIServerSourceClient(t, "mynamespace")
+	apiServerClient := v1.NewMockKnAPIServerSourceClient(t, "mynamespace")
 	apiServerRecorder := apiServerClient.Recorder()
 
 	apiServerRecorder.DeleteAPIServerSource("testsource", errors.New("apiserver source testsource not found"))
@@ -51,3 +50,10 @@ func TestDeleteWithError(t *testing.T) {
 
 	apiServerRecorder.Validate()
 }
+
+func TestDeleteWithNoArgError(t *testing.T) {
+	apiServerClient := v1.NewMockKnAPIServerSourceClient(t, "mynamespace")
+	out, err := executeAPIServerSourceCommand(apiServerClient, nil, "delete")
+	assert.ErrorContains(t, err, "single argument")
+	assert.Assert(t, util.ContainsAll(out, "requires", "single argument"))
+}
