@@ -19,13 +19,14 @@ package container
 import (
 	"errors"
 	"fmt"
+	"os"
 
 	"github.com/spf13/cobra"
 	"knative.dev/client/pkg/kn/commands/flags"
 	knflags "knative.dev/client/pkg/kn/flags"
 
 	"knative.dev/client/pkg/kn/commands"
-	"knative.dev/client/pkg/sources/v1alpha2"
+	v1 "knative.dev/client/pkg/sources/v1"
 )
 
 // NewContainerUpdateCommand for managing source update
@@ -67,9 +68,9 @@ func NewContainerUpdateCommand(p *commands.KnParams) *cobra.Command {
 				return fmt.Errorf("can't update container source %s because it has been marked for deletion", name)
 			}
 
-			b := v1alpha2.NewContainerSourceBuilderFromExisting(source)
+			b := v1.NewContainerSourceBuilderFromExisting(source)
 			podSpec := b.Build().Spec.Template.Spec
-			err = podFlags.ResolvePodSpec(&podSpec, cmd.Flags())
+			err = podFlags.ResolvePodSpec(&podSpec, cmd.Flags(), os.Args)
 			if err != nil {
 				return fmt.Errorf(
 					"cannot update ContainerSource '%s' in namespace '%s' "+
@@ -88,13 +89,9 @@ func NewContainerUpdateCommand(p *commands.KnParams) *cobra.Command {
 			}
 
 			err = srcClient.UpdateContainerSource(cmd.Context(), b.Build())
-			if err != nil {
-				return fmt.Errorf(
-					"cannot update ContainerSource '%s' in namespace '%s' "+
-						"because: %s", name, namespace, err)
+			if err == nil {
+				fmt.Fprintf(cmd.OutOrStdout(), "Container source '%s' updated in namespace '%s'.\n", args[0], namespace)
 			}
-
-			fmt.Fprintf(cmd.OutOrStdout(), "Container source '%s' updated in namespace '%s'.\n", args[0], namespace)
 			return err
 		},
 	}
