@@ -64,69 +64,69 @@ func TestGitOpsOperations(t *testing.T) {
 		assert.Equal(t, "baz-ns", ns)
 	})
 	t.Run("create service foo in foo namespace", func(t *testing.T) {
-		err := fooclient.CreateService(fooSvc)
+		err := fooclient.CreateService(context.Background(), fooSvc)
 		assert.NilError(t, err)
 	})
 	t.Run("wait for foo service in foo namespace", func(t *testing.T) {
-		err, d := fooclient.WaitForService("foo", 5*time.Second, nil)
+		err, d := fooclient.WaitForService(context.Background(), "foo", 5*time.Second, nil)
 		assert.NilError(t, err)
 		assert.Equal(t, 1*time.Second, d)
 	})
 	t.Run("get service foo", func(t *testing.T) {
-		result, err := fooclient.GetService("foo")
+		result, err := fooclient.GetService(context.Background(), "foo")
 		assert.NilError(t, err)
 		assert.DeepEqual(t, fooSvc, result)
 	})
 	t.Run("create service bar in foo namespace", func(t *testing.T) {
-		err := fooclient.CreateService(barSvc)
+		err := fooclient.CreateService(context.Background(), barSvc)
 		assert.NilError(t, err)
 	})
 	t.Run("create service bar in baz namespace", func(t *testing.T) {
-		err := bazclient.CreateService(barSvc)
+		err := bazclient.CreateService(context.Background(), barSvc)
 		assert.NilError(t, err)
 	})
 	t.Run("list services in foo namespace", func(t *testing.T) {
-		result, err := fooclient.ListServices()
+		result, err := fooclient.ListServices(context.Background())
 		assert.NilError(t, err)
 		assert.DeepEqual(t, fooserviceList, result)
 	})
-	t.Run("create service without master directory", func(t *testing.T) {
-		err := diffClusterClient.CreateService(fooSvc)
+	t.Run("create service without tmp directory", func(t *testing.T) {
+		err := diffClusterClient.CreateService(context.Background(), fooSvc)
 		assert.ErrorContains(t, err, "directory 'tmp' not present, please create the directory and try again")
 	})
 	diffClusterClient = NewKnServingGitOpsClient("", c2TempDir)
 	t.Run("create service foo in foo namespace in cluster 2", func(t *testing.T) {
-		err := diffClusterClient.CreateService(fooSvc)
+		err := diffClusterClient.CreateService(context.Background(), fooSvc)
 		assert.NilError(t, err)
 	})
 	t.Run("list services in all namespaces in cluster 1", func(t *testing.T) {
-		result, err := globalclient.ListServices()
+		result, err := globalclient.ListServices(context.Background())
 		assert.NilError(t, err)
 		assert.DeepEqual(t, allServices, result)
 	})
 	t.Run("update service with retry foo", func(t *testing.T) {
-		changed, err := fooclient.UpdateServiceWithRetry("foo", func(svc *servingv1.Service) (*servingv1.Service, error) {
+		changed, err := fooclient.UpdateServiceWithRetry(context.Background(), "foo", func(svc *servingv1.Service) (*servingv1.Service, error) {
 			return svc, nil
 		}, 1)
 		assert.Assert(t, changed)
 		assert.NilError(t, err)
 	})
 	t.Run("update service foo", func(t *testing.T) {
-		changed, err := fooclient.UpdateService(fooUpdateSvc)
+		changed, err := fooclient.UpdateService(context.Background(), fooUpdateSvc)
 		assert.Assert(t, changed)
 		assert.NilError(t, err)
 	})
 	t.Run("check updated service foo", func(t *testing.T) {
-		result, err := fooclient.GetService("foo")
+		result, err := fooclient.GetService(context.Background(), "foo")
 		assert.NilError(t, err)
 		assert.DeepEqual(t, fooUpdateSvc, result)
 	})
 	t.Run("delete service foo", func(t *testing.T) {
-		err := fooclient.DeleteService("foo", 5*time.Second)
+		err := fooclient.DeleteService(context.Background(), "foo", 5*time.Second)
 		assert.NilError(t, err)
 	})
 	t.Run("get service foo", func(t *testing.T) {
-		_, err := fooclient.GetService("foo")
+		_, err := fooclient.GetService(context.Background(), "foo")
 		assert.ErrorType(t, err, apierrors.IsNotFound)
 	})
 }
@@ -155,72 +155,72 @@ func TestGitOpsSingleFile(t *testing.T) {
 		assert.Equal(t, "", ns)
 	})
 	t.Run("create service in single file mode in different formats", func(t *testing.T) {
-		err := fooclient.CreateService(testSvc)
+		err := fooclient.CreateService(context.Background(), testSvc)
 		assert.NilError(t, err)
 
-		err = barclient.CreateService(testSvc)
+		err = barclient.CreateService(context.Background(), testSvc)
 		assert.NilError(t, err)
 
-		err = bazclient.CreateService(testSvc)
+		err = bazclient.CreateService(context.Background(), testSvc)
 		assert.NilError(t, err)
 	})
 	t.Run("retrieve services", func(t *testing.T) {
-		result, err := fooclient.GetService("test")
+		result, err := fooclient.GetService(context.Background(), "test")
 		assert.NilError(t, err)
 		assert.DeepEqual(t, testSvc, result)
 
-		result, err = barclient.GetService("test")
+		result, err = barclient.GetService(context.Background(), "test")
 		assert.NilError(t, err)
 		assert.DeepEqual(t, testSvc, result)
 
-		result, err = bazclient.GetService("test")
+		result, err = bazclient.GetService(context.Background(), "test")
 		assert.NilError(t, err)
 		assert.DeepEqual(t, testSvc, result)
 	})
 	t.Run("update service foo", func(t *testing.T) {
-		changed, err := fooclient.UpdateService(updateSvc)
+		changed, err := fooclient.UpdateService(context.Background(), updateSvc)
 		assert.NilError(t, err)
 		assert.Assert(t, changed)
 
-		changed, err = barclient.UpdateService(updateSvc)
+		changed, err = barclient.UpdateService(context.Background(), updateSvc)
 		assert.NilError(t, err)
 		assert.Assert(t, changed)
 
-		changed, err = bazclient.UpdateService(updateSvc)
+		changed, err = bazclient.UpdateService(context.Background(), updateSvc)
 		assert.NilError(t, err)
 		assert.Assert(t, changed)
 	})
 	t.Run("list services", func(t *testing.T) {
-		result, err := fooclient.ListServices()
+		result, err := fooclient.ListServices(context.Background())
 		assert.NilError(t, err)
 		assert.DeepEqual(t, svcList, result)
 
-		result, err = barclient.ListServices()
+		result, err = barclient.ListServices(context.Background())
 		assert.NilError(t, err)
 		assert.DeepEqual(t, svcList, result)
 
-		result, err = bazclient.ListServices()
+		result, err = bazclient.ListServices(context.Background())
 		assert.NilError(t, err)
 		assert.DeepEqual(t, svcList, result)
 	})
 	t.Run("delete service foo", func(t *testing.T) {
-		err := fooclient.DeleteService("test", 5*time.Second)
+		err := fooclient.DeleteService(context.Background(), "test", 5*time.Second)
 		assert.NilError(t, err)
 
-		err = barclient.DeleteService("test", 5*time.Second)
+		err = barclient.DeleteService(context.Background(), "test", 5*time.Second)
 		assert.NilError(t, err)
 
-		err = bazclient.DeleteService("test", 5*time.Second)
+		err = bazclient.DeleteService(context.Background(), "test", 5*time.Second)
 		assert.NilError(t, err)
 	})
 	t.Run("get service foo", func(t *testing.T) {
-		_, err := fooclient.GetService("test")
+		_, err := fooclient.GetService(context.Background(), "test")
 		assert.ErrorType(t, err, apierrors.IsNotFound)
 
-		_, err = barclient.GetService("test")
+		_, err = barclient.GetService(context.Background(), "test")
 		assert.ErrorType(t, err, apierrors.IsNotFound)
 
-		_, err = bazclient.GetService("test")
+		_, err = bazclient.GetService(context.Background(), "test")
 		assert.ErrorType(t, err, apierrors.IsNotFound)
 	})
 }
